#' @name geonapi
#' @aliases geonapi-package
#' @aliases geonapi
#' 
#' @title 'GeoNetwork' API R Interface
#' @description Provides an R interface to the 'GeoNetwork' API (<https://geonetwork-opensource.org/#api>)
#' allowing to upload and publish metadata in a 'GeoNetwork' web-application and expose it to OGC CSW 
#' Web-Services (Catalogue Service for the Web).
#'  
#'@author Emmanuel Blondel \email{emmanuel.blondel1@@gmail.com}
#'
"_PACKAGE"